@@ -8,6 +8,8 @@ import shutil
 import click
 import subprocess
 
+exec(open("./journalMiner/_version.py").read())  # loads __version__
+
 def get_papers(query, folder_path, limit):
 
     base = 'cmd /c getpapers -q ' # base of getpapers request
@@ -27,8 +29,7 @@ def get_papers(query, folder_path, limit):
     return
 
 def extract_xml(xml_path, keywords):
-
-    ''' Extracts Key Article Data from Paper XML '''
+    # Extracts Key Article Data from Paper XML
 
     with open(xml_path, 'r') as f:
         soup = BeautifulSoup(f, 'html.parser')
@@ -45,11 +46,11 @@ def extract_xml(xml_path, keywords):
         date = 'NaN'
 
     # Extract Key Word Counts and Paper Score
-    content = soup.text.split(' ') # List of words in article without xml tags
     keyword_hits = {}
-    for word in content:
-        if word in keywords:
-            keyword_hits[word] = keyword_hits.get(word, 0) + 1 # Dictionary Counter
+    content = soup.text.lower()
+    for word in keywords:
+        frequency = content.count(word.lower())
+        keyword_hits[word] = frequency
 
     score = sum(keyword_hits.values()) # Calculate overall score for paper
 
@@ -57,7 +58,7 @@ def extract_xml(xml_path, keywords):
 
 def iterate_folder(folder_path, keywords):
 
-    df = pd.DataFrame(columns=['Date', 'Title', 'Score', 'KeyWords']) # Init dataframe
+    df = pd.DataFrame(columns=['Date', 'Title', 'Score']) # Init dataframe
 
     # Iterate through getpapers generated output dir
     for root, dirs, files in os.walk(folder_path):
@@ -65,7 +66,11 @@ def iterate_folder(folder_path, keywords):
             path = os.path.join(root, file)
             if path.endswith('.xml'):
                 date, title, score, keyword_hits = extract_xml(path, keywords)
-                entry = {'Date':date, 'Title':title, 'Score':score, 'KeyWords':keyword_hits}
+                entry = {'Date':date, 'Title':title, 'Score':score}
+                # Create new column for each keyword searched
+                for word in keyword_hits:
+                    entry[word] = keyword_hits[word]
+
                 df = df.append(entry, ignore_index=True) # Add paper data to dataframe
 
     # Order df so highest score first
@@ -74,10 +79,10 @@ def iterate_folder(folder_path, keywords):
     return df
 
 def export_mine(df, query, folder_path):
-
-    ''' Exports mine as .csv and deletes the local mine resources '''
+    # Exports mine as .csv and deletes the local mine resources
 
     # Export df to .csv (Excel)
+    query = query.replace(' ', '_') # Format for multi-word query strings
     entries = df['Title'].count()
     output_path = os.path.join(os.getcwd(), query + '_' + str(entries) + '.csv')
 
@@ -97,7 +102,8 @@ def export_mine(df, query, folder_path):
 @click.command()
 @click.argument('query')
 @click.option('-l', '--limit', default = 1000, type=int, help='Number of papers to mine. Default = 1000' )
-@click.option('-kw', '--keywords', multiple=True, help='Keyword to mine.')
+@click.option('-kw', '--keyword', multiple=True, help='Keyword to mine.')
+@click.version_option(version= __version__ )
 def cli(query, keywords, limit):
 
     """Arguments:\n
@@ -105,10 +111,11 @@ def cli(query, keywords, limit):
     """
 
     # Make sure not overwriting existing folder
-    folder_path = os.path.join(os.getcwd(), query + '_mine')
+    path_query = query.replace(' ', '_') # Format for multi-word query strings
+    folder_path = os.path.join(os.getcwd(), path_query + '_mine')
     count = 1
     while os.path.exists(folder_path):
-        folder_path = os.path.join(os.getcwd(),str(count) + '_' +  query + '_mine')
+        folder_path = os.path.join(os.getcwd(),str(count) + '_' +  path_query + '_mine')
         count += 1
 
     get_papers(query, folder_path, limit)
